In action
=======
![](../../doc/widgets/images/storynavigator_logo_small.png)

This section includes links to projects, events, papers, blogposts, videos, etc. which mention or make use of StoryNavigator.

**Blogs**

[The Orange3 data mining platform for the Social Sciences and Humanities](https://blog.esciencecenter.nl/the-orange3-data-mining-platform-as-a-research-tool-2167336a5c0d)



More coming soon!
